@@ -14,53 +14,55 @@
 ## along with this program.  If not, see
 ## <https://www.gnu.org/licenses/>.
 
-## -*- texinfo -*- 
-## @deftypefn {} {} arduinoio.LibraryBase
-## Base class used for arduino library plugins
-##
-## @seealso{arduino, listArduinoLibraries, addon}
-## @end deftypefn
-##
-## @subheading Properties
-## Base properties are expected to be inherited and overwritten in inherited classes.
-## and are constant in order to query through the metaobject mechanism.
-##
-## @var{LibraryName} - name of the addon library
-##
-## @var{DependentLibraries} - array of dependent library names that must be included when 
-## installing this plugin.
-##
-## @var{CppHeaderFile} - name (if any) of header file that will be included into the arduino
-## project when adding this library.
-##
-## @var{CppSourceFile} - name (if any) of source file that will be included into the arduino
-## project when adding this library.
-##
-## @var{CppClassName} - name of the cpp class for the addon library.
-## project when adding this library.
-##
-## @var{Pins} - pins allocated to the addon
-##
-## @var{Parent} - parent arduino object.
-##
-## @subheading Methods
-## @deftypefn {} {@var{lb} =} LibraryBase ()
-## Constructor of base class
-##
-## The constructor is usually not called but called indirectly from the addon function.
-##
-## @subsubheading Outputs
-## The return value @var{lb} is an object of the arduinio.LibraryBase class.
-##
-## @seealso{arduino, listArduinoLibraries, addon}
-## @end deftypefn
-##
-## @deftypefn {} {} display ()
-## Display the addon in a verbose way.
-## @end deftypefn
-
 
 classdef LibraryBase < handle
+  ## -*- texinfo -*- 
+  ## @deftypefn {} {} arduinoio.LibraryBase
+  ## Base class used for arduino library plugins
+  ##
+  ## @seealso{arduino, listArduinoLibraries, addon}
+  ## @end deftypefn
+  ##
+  ## @subheading Properties
+  ## Base properties are expected to be inherited and overwritten in 
+  ## inherited classes and are constant in order to query through the 
+  ## metaobject mechanism.
+  ##
+  ## @var{LibraryName} - name of the addon library
+  ##
+  ## @var{DependentLibraries} - array of dependent library names that
+  ##  must be included when installing this plugin.
+  ##
+  ## @var{CppHeaderFile} - name (if any) of header file that will be
+  ## included into the arduino project when adding this library.
+  ##
+  ## @var{CppSourceFile} - name (if any) of source file that will be
+  ## included into the arduino project when adding this library.
+  ##
+  ## @var{CppClassName} - name of the cpp class for the addon library.
+  ## project when adding this library.
+  ##
+  ## @var{Pins} - pins allocated to the addon
+  ##
+  ## @var{Parent} - parent arduino object.
+  ##
+  ## @subheading Methods
+  ## @deftypefn {} {@var{lb} =} LibraryBase ()
+  ## Constructor of base class
+  ##
+  ## The constructor is usually not called but called indirectly
+  ## from the addon function.
+  ##
+  ## @subsubheading Outputs
+  ## The return value @var{lb} is an object of the arduinio.LibraryBase class.
+  ##
+  ## @seealso{arduino, listArduinoLibraries, addon}
+  ## @end deftypefn
+  ##
+  ## @deftypefn {} {} display ()
+  ## Display the addon in a verbose way.
+  ## @end deftypefn
+
   # properties that may be overridden in 
   # subclasses
   properties (Access = protected)
@@ -115,10 +117,21 @@ classdef LibraryBase < handle
       else
         printf("        Pins = {\n");
         for i=1:numel(this.Pins)
-          printf("            %s\n", this.Pins{i});
+          if isnumeric(this.Pins{i})
+            printf("            %d\n", this.Pins{i});
+          else
+            printf("            %s\n", this.Pins{i});
+          endif
         endfor
         printf("        }\n");
       endif
     endfunction
+
+    # overrides of arduino that matlab documentation indirectly
+    # seems to indicate in the examples
+    function [dataout, datasize] = sendCommand(this, varargin)
+      [dataout, datasize] = sendCommand(this.Parent, varargin{:}) 
+    endfunction
+
   endmethods
 endclassdef
