@@ -1,4 +1,4 @@
-## Copyright (C) 2018-2019 John Donoghue <john.donoghue@ieee.org>
+## Copyright (C) 2018-2021 John Donoghue <john.donoghue@ieee.org>
 ## 
 ## This program is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
@@ -53,6 +53,18 @@ function retval = boardTypeString (id)
     #  retval = "zero";
     case 41
       retval = "sparkfunsamd21";
+    case 45
+      retval = "due";
+    case 50
+      retval = "mkrzero";
+    case 51
+      retval = "mkr1000";
+    case 60
+      retval = "nano_33_ble";
+    case 100
+      retval = "raspi_pico";
+    case 101
+      retval = "nano_rp2040_connect";
     otherwise
       retval = "unknown";
   endswitch
