@@ -22,11 +22,13 @@
 #include <Arduino.h>
 
 #define VERSION_MAJOR 0
-#define VERSION_MINOR 6
+#define VERSION_MINOR 7
 #define VERSION_PATCH 0
 
-// sparkfun samed21 dev/mini
-#if defined(SERIAL_PORT_USBVIRTUAL)
+#if defined(ARDUINO_SAM_DUE)
+# define OCTAVE_COMMS_PORT SERIAL_PORT_MONITOR
+#elif defined(SERIAL_PORT_USBVIRTUAL)
+  // sparkfun samed21 dev/mini
 # define OCTAVE_COMMS_PORT SERIAL_PORT_USBVIRTUAL
 #else
 # define OCTAVE_COMMS_PORT SERIAL_PORT_MONITOR
@@ -38,7 +40,11 @@ public:
   String libName;
   int id;
 
-  virtual void commandHandler(uint8_t cmdID, uint8_t* inputs, uint8_t payload_size) = 0;
+  virtual void commandHandler(uint8_t cmdID, uint8_t* inputs, uint8_t payload_size);
+
+  // matlab compatability
+  virtual void commandHandler(byte cmdID, byte* inputs, unsigned int payload_size);
+
   virtual void setup();
   virtual void loop();
 
@@ -46,6 +52,7 @@ public:
 
   #define ARDUINO_ERROR       255
   #define ARDUINO_WAIT        254
+  #define ARDUINO_DEBUG       253
   void sendResponseMsg(uint8_t cmdID, const uint8_t *data, uint8_t sz);
   void sendResponseMsg_P(uint8_t cmdID, const uint8_t *data PROGMEM, uint8_t sz);
 
@@ -54,7 +61,7 @@ public:
   void sendUnknownCmdIDMsg();
   void sendInvalidNumArgsMsg();
   void sendWaitMsg();
-  // void debugPrint(const char *,varargs);
+  void debugPrint(const char *, ...);
 };
 
 typedef OctaveLibraryBase LibraryBase;
@@ -84,5 +91,12 @@ private:
 // for matlab compatability
 typedef OctaveArduinoClass MWArduinoClass;
 
+// error strings
+extern const char ERRORMSG_INVALID_NUMBER_OF_ARGS[] PROGMEM;
+extern const char ERRORMSG_INVALID_ARGS[] PROGMEM;
+extern const char ERRORMSG_INVALID_MODE[] PROGMEM;
+extern const char ERRORMSG_INVALID_PIN[] PROGMEM;
+extern const char ERRORMSG_UNIMPLEMENTED[] PROGMEM;
+extern const char ERRORMSG_INVALID_DEVICE[] PROGMEM;
 
 #endif // OCTAVE_LIBRARY_BASE_H
