@@ -55,6 +55,8 @@ classdef arduino < handle
   ## The libraries currently programmed onto the board
   ## @item availablepins
   ## The pins available for use on the board
+  ## @item analogreference
+  ## The analog voltage reference
   ## @end table
   ## @seealso{scanForArduinos, arduinosetup}
   ## @end deftypefn 
@@ -69,6 +71,15 @@ classdef arduino < handle
     name = "";
     debug = false;
   endproperties
+
+  # matlab compatible properties
+  properties (SetAccess = private)
+    AvailablePins = [];
+    Libraries = [];
+    AnalogReference = 5.0;
+    Board = "";
+    Port = "";
+  endproperties
   
   methods (Access = public)
  
@@ -208,6 +219,18 @@ classdef arduino < handle
       m = this.config.mcu;
     endfunction
 
+    function m = get_flags (this)
+      m = this.config.flags;
+    endfunction
+
+    function m = get_endian (this)
+      if bitand(this.config.flags, 0x80) != 0
+        m = "B";
+      else
+        m = "L";
+      endif
+    endfunction
+
     function id = get_lib (this, name)
       idx = find( cellfun(@(x) strcmpi(x.name, name), this.config.libs), 1);
 
@@ -246,6 +269,17 @@ classdef arduino < handle
       info = this.config.pins{idx};
     endfunction
 
+    function info = get_altpin (this, pin)
+      idx = find (cellfun(@(x) (sum(strcmpi (x.altnames, pin))>0), this.config.pins), 1);
+
+      if !isempty (idx)
+        info = this.config.pins{idx};
+      else
+        info = {};
+      endif
+     
+    endfunction
+
     function retval = get_group(this,type)
       retval = {};
 
@@ -291,6 +325,10 @@ classdef arduino < handle
       endif
     endfunction
 
+    function ref = analogreference(this)
+      ref = this.config.voltref;
+    endfunction
+
     function pins = availablepins(this)
       pins = {};
       for i=1:numel (this.config.pins)
@@ -351,6 +389,27 @@ classdef arduino < handle
     function v = board_voltage (this)
       v = this.config.voltref;
     endfunction
+
+    function v = get.AvailablePins (this)
+      v = availablepins(this);
+    endfunction
+
+    function v = get.Libraries (this)
+      v = libraries(this);
+    endfunction
+
+    function v = get.AnalogReference (this)
+      v = this.config.voltref;
+    endfunction
+
+    function v = get.Board (this)
+      v = this.config.board;
+    endfunction
+
+    function v = get.Port (this)
+      v = this.config.port;
+    endfunction
+
   endmethods 
 endclassdef
 
